import React from 'react';
import { connect } from 'dva';
import Board from '../components/Board';
import  style from './game.css';

function calculateWinner(squares) {
  const lines = [
    [0, 1, 2],
    [3, 4, 5],
    [6, 7, 8],
    [0, 3, 6],
    [1, 4, 7],
    [2, 5, 8],
    [0, 4, 8],
    [2, 4, 6]
  ];
  for (let i = 0; i < lines.length; i++) {
    const [a, b, c] = lines[i];
    if (squares[a] && squares[a] === squares[b] && squares[a] === squares[c]) {
      return squares[a];
    }
  }
  return null;
}

const Game = ({ history, stepNumber, xIsNext, dispatch }) => {
  const current = history[stepNumber];
  const winner = calculateWinner(current.squares);
  const moves = history.map((step, move) => {
    const desc = move ?
      'Go to move #' + move :
      'Go to game start';
    return (
      <li key={move}>
          <button onClick={() => dispatch({type: 'game/jumpTo', payload: move})}>{desc}</button>
      </li>
    )
  });
  let status;
  if (winner) {
    status = "Winner: " + winner;
  } else {
    status = "Next player: " + (xIsNext ? "X" : "O");
  }
  return (
    <div className={style.game}>
      <div className="game-board">
        <Board
          squares={current.squares}
          dispatch={dispatch}
        />
      </div>
      <div className="game-info">
        <div>{status}</div>
        <ol>{moves}</ol>
      </div>
    </div>
  )
}
Game.propTypes = {
};
const mapStateToProps = (state) => {
  return {
    history: state.game.history,
    stepNumber: state.game.stepNumber,
    xIsNext: state.game.xIsNext
  }
}
export default connect(mapStateToProps)(Game);
